//Функция генерации обучающих данных (для динамики выходных характеристик)
function [SystemOutputCharacteristics,..//Выходные характеристики
          SystemParametrsIndexes,..//Индексы параметров системы, для которых рассчитывались выходные характеристики
          SystemParametrs,..//Параметры системы, для которых рассчитывались выходные характеристики
          TimesMomemts..//Моменты времени
          ]=ModelingSystemDynamicTimeGrid(SystemOutputCharacteristicsNames,...//Имена выходных характеристик системы
                                          SystemOutputCharacteristicsIndexes,...//Индексы выходных характеристик системы
                                          SystemShemaName,...//Имя схемы системы
                                          TimeMoments,...//Моменты времени
                                          SystemParametrsNames,...//Имена параметров, определяющих динамику
                                          SystemParametrsValues,...//Значения параметров, определяющих динамику
                                          absolutTolErr,..//Максимальное значение абсолютной ошибки
                                          relativeTolErr,..//Минимальное значение относительной ошибки
                                          simulationTime,..//Время симуляции
                                          timeStepMax,..//Максимальный шаг интергирования по времени
                                          Solver,..//Решатель
                                          toleranceTime..//Максимальная ошибка времени
                                          )
    //Проверяем число аргументов
    [nOut,nArg] = argn();//Число аргументов
    if nArg < 6 then
        error('Function ModelingSystemDynamicTimeGrid takes 6 or more arguments');
    end
    
    //Восполняем недостающие аргументы
    select nArg
    case 6 then
        absolutTolErr = [];
        relativeTolErr = [];
        simulationTime = [];
        timeStepMax = [];
        Solver = [];
        toleranceTime = [];
    case 7 then
        relativeTolErr = [];
        simulationTime = [];
        timeStepMax = [];
        Solver = [];
        toleranceTime = [];
    case 8 then
        simulationTime = [];
        timeStepMax = [];
        Solver = [];
        toleranceTime = [];
    case 9 then
        timeStepMax = [];
        Solver = [];
        toleranceTime = [];
    case 10 then
        Solver = [];
        toleranceTime = [];
    case 11 then
        toleranceTime = [];
    end
           
    //Приволим аргументы к виду матрица - строка
    SystemOutputCharacteristicsIndexes = matrix(SystemOutputCharacteristicsIndexes, 1, -1);
    TimeMoments = matrix(TimeMoments, 1, -1);
        
    //Проверяем корректность аргументов
    if (~isempty(SystemOutputCharacteristicsNames)) &&..
       (type(SystemOutputCharacteristicsNames) ~= 10) then
        error('The SystemOutputCharacteristicsIndexes argument of function ModelingSystemDynamicTimeGrid is matrix of string');
    end
    if type(SystemOutputCharacteristicsIndexes) ~= 1 then
        error('The SystemOutputCharacteristicsIndexes argument of function ModelingSystemDynamicTimeGrid is matrix of integer');
    end
    if size(SystemOutputCharacteristicsNames,'*') ~= size(SystemOutputCharacteristicsIndexes,'*') then
        error('The sizes of arguments SystemOutputCharacteristicsNames and SystemOutputCharacteristicsIndexes of function ModelingSystemDynamicTimeGrid must be equality');
    end
    if (type(SystemShemaName) ~= 10) ||..
       (size(SystemShemaName, '*') > 1) then
        error('The SystemShemaName argument of function ModelingSystemDynamicTimeGrid is scalar string');
    end
    if type(TimeMoments) == 17 then
        for ind=1:size(TimeMoments,'*')
            if type(TimeMoments{ind}) ~= 1 then
                error('The TimeMoments argument of function ModelingSystemDynamicTimeGrid is cell-array of functions');
            end
        end
    else
        error('The TimeMoments argument of function ModelingSystemDynamicTimeGrid is cell-array of real array');
    end
    nCurves = size(SystemParametrsValues)(1);//Число кривых
    if size(TimeMoments,'*') ~= nCurves then
        error('The number of times moments arrays must be equal to the number of possible dynamics');
    end
    
    //Получаем список уже открытых графических окон
    Wins_begin = winsid();
    
    //Загружаем схему системы
    SystemShema = xcosDiagramToScilab(SystemShemaName);
    
    //Вычислительный эксперимент
    SystemOutputCharacteristics = [];
    if nOut >= 2 then
        SystemParametrsIndexes = [];
    end
    if nOut >= 4 then
        TimesMomemts = [];
    end
    for ind=1:nCurves
        //Проводим вычислительный эксперимент
        systemOutputCharacteristics = ComputingExperiment(SystemOutputCharacteristicsNames,...//Имена выходных характеристик системы
                                                          SystemShema,..//Схема системы
                                                          SystemParametrsNames,..//Имена параметров
                                                          SystemParametrsValues(ind,:),..//Значения параметров
                                                          absolutTolErr(ind),..//Максимальное значение абсолютной ошибки
                                                          relativeTolErr(ind),..//Минимальное значение относительной ошибки
                                                          simulationTime(ind),..//Время симуляции
                                                          timeStepMax(ind),..//Максимальный шаг интергирования по времени
                                                          Solver(ind),..//Решатель
                                                          toleranceTime(ind)..//Максимальная ошибка времени
                                                          );
                                                          
        //Приводим выходные характеристики системы к одному временному масштабу
        [DynamicsInTimeGrid,..
         mTimesMoments] = DynamicsToTimeGrid(systemOutputCharacteristics,..//Массив динамик
                                             SystemOutputCharacteristicsIndexes,..//Индексы динамик (в именах)
                                             TimeMoments{ind}..//Моменты времени
                                             );
                                                              
        //Приводим параметры и формируем результат
        SystemOutputCharacteristics = [SystemOutputCharacteristics;..
                                       DynamicsInTimeGrid];    
        if nOut >= 2 then
            SystemParametrsIndexes = [SystemParametrsIndexes;..
                                      repmat(ind,..
                                             [1,size(DynamicsInTimeGrid)(1)])'];
        end
        if nOut >= 4 then
            TimesMomemts = [TimesMomemts;..
                            mTimesMoments];
        end
    end
    
    //Формируем матрицу выходных параметров системы    
    if nOut >= 3 then
        SystemParametrs = SystemParametrsValues(SystemParametrsIndexes,:);//Формируем матрицу параметров системы
    end
    
    //Закрываем графические окна, открывшиеся в результате вычислительного эксперимента
    Wins_end = winsid();//Все открытые графические окна
    Wins = setdiff(Wins_end,Wins_begin);//Получаем графические окна, которые были открыты, и которые надо закрыть
    for win=matrix(Wins,1,-1)//Закрываем открытые графические окна
        delete(scf(win));//Закрываем окно
    end
endfunction

//Приведение динамик к единой заданной пользователем временной сетке
function [DynamicsInTimeGrid,..//Динамики в единой временной сетке
          TimesMoments..//Моменты времени
          ]=DynamicsToTimeGrid(Dynamics,..//Массив динамик
                               DynamicsIndexes,..//Индексы динамик (в именах)
                               TimesMoments..//Моменты времени
                               )
    //Проверяем корректность аргументов
    if isempty(Dynamics) || isempty(DynamicsIndexes)  then
        DynamicsInTimeGrid = [];
        return;
    end
    
    //Приводим моменты времени к вектору-столбцу
    TimesMoments = matrix(TimesMoments,-1,1);
    
    //Выполняем выборку
    DynamicsInTimeGrid = [];
    for ind=1:size(DynamicsIndexes,'*')//Вспомогательная функция фильтрации по индексу
        dynamicAfterConvercion = interp1(Dynamics(ind).time,...
                                         Dynamics(ind).values(:,DynamicsIndexes(ind)),...
                                         TimesMoments, 'spline', 'extrap');
        DynamicsInTimeGrid = [DynamicsInTimeGrid,..
                              dynamicAfterConvercion];
    end
endfunction
